==> flutter_windows_v1.2.1-beta.zip: flutter/.pub-cache/hosted/pub.dartlang.org/built_value-6.3.0/test/date_time_serializer_test.dart <==
// Copyright (c) 2017, Google Inc. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

import 'package:built_value/serializer.dart';
import 'package:test/test.dart';

void main() {
  final serializers = new Serializers();

  group('DateTime with known specifiedType', () {
    final data = new DateTime.utc(1980, 1, 2, 3, 4, 5, 6, 7);
    final serialized = data.microsecondsSinceEpoch;
    final specifiedType = const FullType(DateTime);

    test('can be serialized', () {
      expect(serializers.serialize(data, specifiedType: specifiedType),
          serialized);
    });

    test('can be deserialized', () {
      expect(serializers.deserialize(serialized, specifiedType: specifiedType),
          data);
    });

    test('serialize throws if not UTC', () {
      expect(() => serializers.serialize(new DateTime.now()),
          throwsA(const TypeMatcher<ArgumentError>()));
    });
  });

  group('DateTime with unknown specifiedType', () {
    final data = new DateTime.utc(1980, 1, 2, 3, 4, 5, 6, 7);
    final serialized = ['DateTime', data.microsecondsSinceEpoch];
    final specifiedType = FullType.unspecified;

    test('can be serialized', () {
      expect(serializers.serialize(data, specifiedType: specifiedType),
          serialized);
    });

    test('can be deserialized', () {
      expect(serializers.deserialize(serialized, specifiedType: specifiedType),
          data);
    });
  });
}

==> flutter_windows_2.1.0-12.2.pre-beta.zip: flutter/.pub-cache/hosted/pub.dartlang.org/built_value-7.1.0/test/date_time_serializer_test.dart <==
// Copyright (c) 2017, Google Inc. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

import 'package:built_value/serializer.dart';
import 'package:test/test.dart';

void main() {
  var serializers = Serializers();

  group('DateTime with known specifiedType', () {
    var data = DateTime.utc(1980, 1, 2, 3, 4, 5, 6, 7);
    var serialized = data.microsecondsSinceEpoch;
    var specifiedType = const FullType(DateTime);

    test('can be serialized', () {
      expect(serializers.serialize(data, specifiedType: specifiedType),
          serialized);
    });

    test('can be deserialized', () {
      expect(serializers.deserialize(serialized, specifiedType: specifiedType),
          data);
    });

    test('serialize throws if not UTC', () {
      expect(() => serializers.serialize(DateTime.now()),
          throwsA(const TypeMatcher<ArgumentError>()));
    });
  });

  group('DateTime with unknown specifiedType', () {
    var data = DateTime.utc(1980, 1, 2, 3, 4, 5, 6, 7);
    var serialized = ['DateTime', data.microsecondsSinceEpoch];
    var specifiedType = FullType.unspecified;

    test('can be serialized', () {
      expect(serializers.serialize(data, specifiedType: specifiedType),
          serialized);
    });

    test('can be deserialized', () {
      expect(serializers.deserialize(serialized, specifiedType: specifiedType),
          data);
    });
  });
}
